@@ -22,7 +22,12 @@ DYNAMIC_LINK_URL_BASE_COMPONENT = getattr(
 
 # Prefixes if FORCE_SCRIPT_NAME
 DYNAMIC_LINK_URL = ''
-if settings.FORCE_SCRIPT_NAME:
+DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME = getattr(
+    settings,
+    'DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME',
+    False
+)
+if DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME and settings.FORCE_SCRIPT_NAME:
     DYNAMIC_LINK_URL = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
 else:
     DYNAMIC_LINK_URL = '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
